#if !defined(__PCPstruct_PACKAGE)
#define __PCPstruct_PACKAGE

#include "petschead.h" /* VE was ptscimpl . necessary? */
#include "vec.h"
#include "mat.h"
#include "ksp.h"
#include "pc.h"
#include "parpre_pc.h"
#include "sles.h"


/* VE This should accomodate all parallel preconditioners */
extern int VecPipelineSetCustomPipelineFromPCPstruct
(VecPipeline,PCParallelStruct*);

#endif

/* ???
struct _PCParallel_PipeInfo {
  CustomPipelineType pipe_type;
  int mytid,numtids;
/ * later add a union of stuff and stuff * /
} ;
*/

